@@ -25,7 +25,7 @@ perl -MDevel::Cover xt/release/00_Job/99_pod_coverage.t
 perl -MDevel::Cover t/01_JobQueue/00_compile.t
 perl -MDevel::Cover t/01_JobQueue/01_new.t
 perl -MDevel::Cover t/01_JobQueue/02_add_job.t
-perl -MDevel::Cover t/01_JobQueue/03_check_job_status.t
+perl -MDevel::Cover t/01_JobQueue/03_get_job_status.t
 perl -MDevel::Cover t/01_JobQueue/04_load_job.t
 perl -MDevel::Cover t/01_JobQueue/05_get_next_job.t
 perl -MDevel::Cover t/01_JobQueue/06_update_job.t
